%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% If locking occurs, calculates the time at which the ball will be
% relaunched, based off of the bar accelerations and gravity.
% If no such time exists, returns terminal = 1 and simulation ends
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [launchConditions, terminal, launched] = calculateLaunch(postImpact, Amp, Phase, w, g);

terminal = 0;
launched = 0;
step = 1/1000;    % One five-hundredth of a period

% Ball sits on the bar until it reaches a location where the acceleration
% of the bar is greater than the acceleration due to gravity
for time = [postImpact(1) : step : postImpact(1) + 1]
    BAR = Amp.*sin(w*(time) + Phase);
    BALL = [ postImpact(4)*(time-postImpact(1)) + postImpact(2); -0.5*g*(time-postImpact(1))^2 + postImpact(5)*(time-postImpact(1)) + postImpact(3) ];
    theta = BAR(3);
    R = [ BALL(1) - BAR(1) ] / cos(theta);
    omega = Amp(3)*w(3)*cos(w(3)*time + Phase(3));
    v = R*omega;
    a_t = -R*Amp(3)*w(3)^2*sin(w(3)*time + Phase(3));
    a_n = R*omega^2;
    Amp_bar_z = -Amp(2)*w(2)*sin(w(2)*time + Phase(2)) + a_t*cos(theta) - a_n*sin(theta);
    if (Amp_bar_z < -g) 
        launched = 1;
        break
    end
end

% The ball is re-launched with zero relative velocity
if (launched)
    t3 = time;
    x3 = BALL(1);
    z3 = BAR(2) + R*sin(theta); 
    Vx3 = Amp(1)*w(1)*cos(w(1)*t3 + Phase(1)) - v*sin(theta);
    Vz3 = Amp(2)*w(2)*cos(w(2)*t3 + Phase(2)) + v*cos(theta);
    launchConditions = [t3, x3, z3, Vx3, Vz3, 0];

% If the conditions do not foster relaunching, simulation is terminated
else
    terminal = 1;
    launchConditions = [postImpact(1), 0, 0, 0, 0, 0];
end
