%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Uses the time of impact and information regarding the previous impact
%     to calculate the impact velocities and positions of the ball
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function postImpact = impact(preImpact, t2, Amp, Phase, w, g, e_n, e_t, islocked, del)

% Obtain expression for radial distance
BAR = Amp.*sin(w*(t2) + Phase);
BALL = [ preImpact(4)*(t2-preImpact(1)) + preImpact(2); -0.5*g*(t2-preImpact(1))^2 + preImpact(5)*(t2-preImpact(1)) + preImpact(3) ];
R = [ BALL(1) - BAR(1) ] / cos(BAR(3));
% Calculate x, z coordinates where the impact occurs, based of off the
    % time, t2
x2 = polyval([preImpact(4) preImpact(2)], t2 - preImpact(1));
if (del > 0)
    del = 0;
end
z2 = polyval([-0.5*g preImpact(5) preImpact(3)], t2 - preImpact(1)) - del;
t_peak = preImpact(5)/g;
z_peak = polyval([-0.5*g preImpact(5) preImpact(3)], t_peak);
del_z = z_peak - z2;
% Calculate pre-impact velocity in the z-direction
Vz = sqrt(2*g*abs(del_z));
if (del_z < 0)
    Vz = -Vz;
end

% Calculate the angle, theta, and the pre-impact velocities
theta = BAR(3);
ROT = [cos(theta), sin(theta); -sin(theta), cos(theta)];    % Rotation matrix
V_pre = ROT*[preImpact(4); Vz];    % Pre-impact velocity (bar frame)
% Break down bar velocity into terms normal and tangential
V_n_bar = Amp(1)*w(1)*cos(w(1)*t2 + Phase(1))*sin(theta) + Amp(2)*w(2)*cos(w(2)*t2 + Phase(2))*cos(theta)...
    + R*Amp(3)*w(3)*cos(w(3)*t2+ Phase(3));
V_t_bar = Amp(1)*w(1)*cos(w(1)*t2 + Phase(1))*cos(theta) + Amp(2)*w(2)*cos(w(2)*t2 + Phase(2))*sin(theta);
% Equations for post-impact velocity, normal and tangential
V_n_post = e_n*[V_pre(2) + V_n_bar] + V_n_bar;
V_t_post = e_t*[V_pre(1)];
ROT = [cos(-theta), sin(-theta); -sin(-theta), cos(-theta)];    % Rotation matrix
V_post = ROT*[V_t_post; V_n_post];    % Post impact velocity, x and z (lab frame);

postImpact = [t2, x2, z2, V_post(1), V_post(2), islocked];
