%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculates the trajectories in between the impact points, 
%     saves the values in matrix "N"
% If indicated by the user, plots the trajectories
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function N = plotTraj(P, initCond, Amp, Phase, w, g, terminal, out_of_bounds, ind, plotting)

max_time = P(end,1);
num_points = 50;    % Number of points per bounce
N = zeros(size(P,1)*num_points + size(P,1), 5);
index = 1;

% Plot bounces
IMP = initCond;
for i = [1 : size(P, 1)]
    if (i ~= 1)
        IMP = P(i - 1, :);
    end
    time_step = [P(i, 1) - IMP(1)] / num_points;
    for time = [IMP(1) : time_step : P(i, 1)]
        if ((terminal || out_of_bounds) && i == ind)
            break
        end
        N(index, 1) = time;
        % If the ball is locked
        if (i ~= 1 && IMP(6) == 1)
            BAR = Amp.*sin(w*(time) + Phase);
            BALL = [ IMP(4)*(time-IMP(1)) + IMP(2); -0.5*g*(time-IMP(1))^2 + IMP(5)*(time-IMP(1)) + IMP(3) ];
            R = [ BALL(1) - BAR(1) ] / cos(BAR(3));
            N(index, 2) = BAR(1) + R*cos(BAR(3));
            N(index, 3) = BAR(2) + R*sin(BAR(3));  
        else
            N(index, 2) = polyval([IMP(4) IMP(2)], time - IMP(1));
            N(index, 3) = polyval([-0.5*g IMP(5) IMP(3)], time - IMP(1));
        end
        N(index, 4) = Amp(1)*sin(w(1)*time + Phase(1));
        N(index, 5) = Amp(2)*sin(w(2)*time + Phase(2));
        index = index + 1;
    end
    if ((terminal || out_of_bounds) && i == ind)
        break
    end
end
if (plotting)
    disp('Plotting...');
    plot(N(:,1), N(:,3),  N(:,1), N(:,5))
end